<?php

namespace Bydedi\Tracking\Google;

/**
 * Class Analytics
 * @package Bydedi\Tracking\Google
 */
class Analytics
{
    /**
     * @var bool
     */
    protected static $isInit = false;

    /**
     * @var array|null $config
     */
    protected static $config = null;

    /**
     * @param array $config
     */
    public static function init($config = array())
    {
        self::$config = $config;
    }

    /**
     * Check if it's initialized.
     * If not trigger a warning error
     */
    protected static function triggerErrorIfNotInit()
    {
        if (is_null(self::$config)) {
            trigger_error("Google Analytics n'est pas initialisé", E_USER_WARNING);
        }
    }

    public static function common($param)
    {
        if (self::$isInit == true) {
            return "";
        }

        self::$isInit = true;

        $tracker = "
        <script>
          (function(i,s,o,g,r,a,m){i['GoogleAnalyticsObject']=r;i[r]=i[r]||function(){
          (i[r].q=i[r].q||[]).push(arguments)},i[r].l=1*new Date();a=s.createElement(o),
          m=s.getElementsByTagName(o)[0];a.async=1;a.src=g;m.parentNode.insertBefore(a,m)
          })(window,document,'script','//www.google-analytics.com/analytics.js','ga');
          ga('create', '".self::$config['id']."', 'auto');
        </script>
        ";

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $tracker);
        }
    }

    public static function getVisites($param = array())
    {

        self::common($param);

        $tracker = "<script>ga('send', 'pageview');</script>";

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position'], $tracker);
        }

        return $tracker;
    }

    public static function paiement($param = array())
    {

        self::common($param);

        $out = "<script>\n";
        $out.= "ga('require', 'ecommerce')\n";

        // transaction
        $out.= "ga('ecommerce:addTransaction', {\n";
        $out.= "'id': '".$param['extra']['commande_id']."',\n"; // Transaction ID. obligatoire
        $out.= "'affiliation': '".$param['extra']['commande_referer']."',\n"; // Affilié non obligatoire
        $out.= "'revenue': '".$param['extra']['commande_total_ttc']."',\n"; // Total.
        $out.= "'shipping': '".$param['extra']['commande_port_ttc']."',\n"; // frais envoi.
        $out.= "'tax': '".round($param['extra']['commande_total_taxe'], 2)."'\n"; // Tax.
        $out.= "});\n";

        foreach ($param['extra']['produits'] as $produit) {
            $categorieName = '';
            if (!empty($produit['categories'])) {
                if (!empty($produit['categories'][0]['grand_parent_nom'])) {
                    $categorieName .= $produit['categories'][0]['grand_parent_nom'] . ',';
                }

                if (!empty($produit['categories'][0]['parent_nom_nom'])) {
                    $categorieName .= $produit['categories'][0]['parent_nom_nom'] . ',';
                }

                if (!empty($produit['categories'][0]['categorie_nom_nom'])) {
                    $categorieName .= $produit['categories'][0]['categorie_nom_nom'];
                }
            }

            $out.= "ga('ecommerce:addItem', {\n";
            $out.= "'id': '".$param['extra']['commande_id']."',\n"; // Transaction ID. obligatoire
            $out.= "'name': '".$produit['produit_nom']."',\n"; // Nom produit. obligatoire
            $out.= "'sku': '".$produit['produit_ref']."',\n"; // Numero commande.
            $out.= "'category': '".$categorieName."',\n"; // Categorie produit.
            $out.= "'price': '".$produit['prix_ttc']."',\n"; // Prix unitaire.
            $out.= "'quantity': '".$produit['qte']."'\n"; // Quantite.
            $out.= "});\n";
        }

        $out.= "ga('ecommerce:send');\n";
        $out.= "</script>\n";

        if (isset($param['smarty'])) {
            $param['smarty']->reassign(self::$config['position_paiement'], $out);
        }
    }
}
